@@ -34,7 +34,13 @@ extern void PerlXlib_XEvent_pack(XEvent *s, HV *fields, Bool consume);
 extern void PerlXlib_XEvent_unpack(XEvent *s, HV *fields);
 extern void PerlXlib_XVisualInfo_pack(XVisualInfo *s, HV *fields, Bool consume);
 extern void PerlXlib_XVisualInfo_unpack(XVisualInfo *s, HV *fields);
+extern void PerlXlib_XWindowAttributes_pack(XWindowAttributes *s, HV *fields, Bool consume);
+extern void PerlXlib_XWindowAttributes_unpack(XWindowAttributes *s, HV *fields);
 extern void PerlXlib_XSetWindowAttributes_pack(XSetWindowAttributes *s, HV *fields, Bool consume);
 extern void PerlXlib_XSetWindowAttributes_unpack(XSetWindowAttributes *s, HV *fields);
+extern void PerlXlib_XWindowChanges_pack(XWindowChanges *s, HV *fields, Bool consume);
+extern void PerlXlib_XWindowChanges_unpack(XWindowChanges *s, HV *fields);
 extern void PerlXlib_XSizeHints_pack(XSizeHints *s, HV *fields, Bool consume);
 extern void PerlXlib_XSizeHints_unpack(XSizeHints *s, HV *fields);
+extern void PerlXlib_XRectangle_pack(XRectangle *s, HV *fields, Bool consume);
+extern void PerlXlib_XRectangle_unpack(XRectangle *s, HV *fields);
