@@ -8,7 +8,7 @@ use base qw(Exporter DynaLoader);
 use Carp;
 use Try::Tiny;
 
-our $VERSION = '0.13';
+our $VERSION = '0.14';
 
 sub dl_load_flags { 1 } # Make PerlXLib.c functions available to other XS modules
 
@@ -1224,7 +1224,7 @@ None of these functions are exportable.
 =head3 XCompositeVersion
 
   my $version_integer= X11::Xlib::XCompositeVersion()
-    if X11::Xlib->can('X11::Xlib::XCompositeVersion');
+    if X11::Xlib->can('XCompositeVersion');
 
 =head3 XCompositeQueryExtension
 
@@ -1233,8 +1233,12 @@ None of these functions are exportable.
 
 =head3 XCompositeQueryVersion
 
-  my ($major, $minor)= $display->XCompositeQueryExtension
-    if $display->can('XCompositeQueryExtension');
+  my ($major, $minor)= $display->XCompositeQueryVersion
+    if $display->can('XCompositeQueryVersion');
+  # or, to request "no higher than version X":
+  my ($major, $minor)= (1,2);
+  $display->XCompositeQueryVersion($major, $minor) # alters these vars
+    or die;
 
 =head3 XCompositeRedirectWindow
 
